<?php

namespace App\modele;

use App\gateway\ImageManager;
use App\metier\Alumni;
use App\metier\Offre;
use App\metier\Experience;
use App\metier\Formation;
use App\metier\Profil;
use App\gateway\Connection;
use App\gateway\ExperienceGateway;
use App\gateway\FormationGateway;
use App\gateway\ProfilGateway;

class MembreModele extends UtilisateurModele
{

    private $con;
    protected $experienceGw;
    protected $formationGw;
    protected $profilGw;

    public function __construct()
    {   
        $this->con = new Connection(DB_HOST,DB_USER,DB_PASS);
        $this->experienceGw = new ExperienceGateway($this->con);
        $this->formationGw = new FormationGateway($this->con);
        $this->profilGw = new ProfilGateway($this->con);
    }

    /**
     * @description modifier photo de profil
     */
    public function updateProfilPhoto() : bool
    {
        // TO DO
        return false;
    }


    /**
     * @description modifier formation
     * 
     */
    public function updateFormation() : bool
    {
        // TO DO
        return false;
    }

    public function getProfilById($idProfil) : ?array 
    {
        $data = $this->profilGw->getProfilById($idProfil);
        $profil = array();

        foreach($data as $row)
        {
            $profil[] = new Profil(
                $row['id'],
                $row['nom'],
                $row['prenom'],
                $row['email'],
                $row['image'] ?? null,
                $row['cv'] ?? null,
                $row['linkedinURL'] ?? null,
                $row['githubURL'] ?? null,
                $row['portfolioURL'] ?? null
            );
        }
        return $profil;
    }

    /**
     * @description Récupérer l'expériences en fonction de l'id
     */
    public function getExperienceById($idProfil) : ?array 
    {
        $data = $this->experienceGw->getExperienceFromId($idProfil);
        $experience = array();

        foreach($data as $row)
        {
            $experience[] = new Experience(
                $row['id'],
                $row['profil'],
                $row['intitule'],
                $row['dateBegin'],
                $row['dateEnd'],
                $row['industryName'],
                $row['currentJob']
            );
        }
        return $experience;
    }

    /**
     * @description Récupérer les expériences de l'utilisateurs en cours
     */
    public function getExperienceByProfil($idProfil) : ?array 
    {
        $data = $this->experienceGw->getExperienceFromProfil($idProfil);
        $experience = array();

        // var_dump($data);
        foreach($data as $row)
        {
            $experience[] = new Experience(
                $row['id'],
                $row['profil'],
                $row['intitule'],
                $row['dateDebut'],
                $row['dateFin'],
                $row['nomEntreprise'],
                $row['currentJob']
            );
        }
        // var_dump($experience);
        return $experience;
    }

    /**
     * @description ajouter Experience
     */
    public function addExperience($idExperience, string $intitule, string $dateDeb, string $dateFin, string $nomEntreprise, ?string $currentJob)
    {
        $exp = new Experience(
            $this->experienceGw->getNewId(),
            $idExperience,
            $intitule,
            $dateDeb,
            $dateFin,
            $nomEntreprise,
            $currentJob
        );
        var_dump($exp);

        $this->experienceGw->addExperience($exp);

    }

    /**
     * @description supprimer une expérience
     */
    public function deleteExperience($id)
    {
        $this->experienceGw->deleteExperience($id);
    }

    /**
     * @description Récupérer les formations de l'utilisateurs en cours
     */
    public function getFormationByProfil($idProfil) : ?array 
    {
        $data = $this->formationGw->getFormationFromProfil($idProfil);
        $formation = array();

        // var_dump($data);
        foreach($data as $row)
        {
            $formation[] = new Formation(
                $row['id'],
                $row['profil'],
                $row['nom'],
                $row['ville'],
                $row['dateDeb'],
                $row['dateFin'],
                $row['currentFormation']
            );
        }
        // var_dump($formation);
        return $formation;
    }

    /**
     * @description ajouter une formation
     */
    public function addFormation($idExperience, string $nom, string $ville, string $dateDeb, string $dateFin, ?string $currentFormation)
    {
        $form = new Formation(
            $this->experienceGw->getNewId(),
            $idExperience,
            $nom,
            $ville,
            $dateDeb,
            $dateFin,
            $currentFormation
        );

        $this->formationGw->addFormation($form);
    }

    /**
     * @description supprimer une formation
     */
    public function deleteFormation($id)
    {
        $this->formationGw->deleteFormation($id);
    }

    /**
     * @description modifier experience
     */
    public function updateExperience() : bool
    {
        // TO DO
        return false;
    }

    /**
     * @description changer mot de passe
     * @param string $oldHash ancien hash
     * @param string $newHash nouveau hash
     */
    public function updatePasswd(string $oldHash,string $newHash) : bool
    {
        // TO DO
        return false;
    }



    public function publishOffer(string $img, string $logo)
    {
        $desc = $_POST["description"];
        $descposte = $_POST["descriptPoste"];
        $nom = $_POST["name"];
        $ville = $_POST["ville"];
        $entreprise = $_POST["entreprise"];
        $profilRecherche = $_POST["profilRecherche"];
        $mail = $_POST["mail"];
        $num = $_POST["num"];
        $site = $_POST["site"];
        $exp = $_POST["choixExp"];
        $typeContrat = $_POST["typeContrat"];
        $niveauEtudes = $_POST["education"];
        $date = new \DateTime();

        if(isset($_POST["fullRemote"]))
        {
            $remote = true;
        }
        else $remote = false;

        // à la place de NULL passer id utilisateur créateur offre
        $offre = new Offre($this->offreGw->getNewId(),
            new Alumni(intval($_SESSION['id']),"test.mail@icloud.fr","",$_SESSION['role'],$_SESSION['nom'],$_SESSION['prenom']),
            $nom,
            $desc,
            $img,
            $logo,
            $typeContrat,
            $ville,
            $entreprise,
            $descposte,
            $profilRecherche,
            $exp,
            $niveauEtudes,
            $mail,
            $num,
            $site,
            $remote,
            $date);

        $this->offreGw->addOffers($offre);

        return $offre;
    }

    public function deleteOffer(Offre $offre)
    {
        $this->offreGw->deleteOffer($offre->getId());
        ImageManager::deleteImg($offre->getImg());
        ImageManager::deleteImg($offre->getLogo());

    }


}